==> pytelegraf-0.1.0-py2-none-any.whl: telegraf/protocol.py <==
from telegraf.utils import format_string, format_value


class Line(object):
    def __init__(self, measurement, values, tags={}, timestamp=None):
        assert measurement, "Must have measurement"
        assert values, "Must have values"

        # Name of the actual measurement
        self.measurement = measurement
        # Single value or a dict of value_name: value pairs
        self.values = values
        # Dict of tags if any
        self.tags = tags
        # User provided timestamp if any
        self.timestamp = timestamp

    def get_output_measurement(self):
        """
        Formats and escapes measurement name that can be rendered to line protocol
        """
        return format_string(self.measurement)

    def get_output_values(self):
        """
        Return an escaped string of comma separated value_name: value pairs
        """
        # Handle primitive values here and implicitly convert them to a dict because
        # it allows the API to be simpler.

        # Also influxDB mandates that each value also has a name so the default name
        # for any non-dict value is "value"
        if not isinstance(self.values, dict):
            metric_values = {'value': self.values}
        else:
            metric_values = self.values

        # Get the lexicographically ordered list of value names first
        sorted_value_names = sorted(metric_values.keys(), key=str.lower)
        # Then get the list of sorted value_name: value tuples
        sorted_values = [(value_name, metric_values[value_name]) for value_name in sorted_value_names]

        return ",".join("{0}={1}".format(format_string(k), format_value(v)) for k, v in sorted_values)

    def get_output_tags(self):
        """
        Return an escaped string of comma separated tag_name: tag_value pairs

        Tags should be sorted by key before being sent for best performance. The sort should
        match that from the Go bytes. Compare function (http://golang.org/pkg/bytes/#Compare).
        """

        # Get the lexicographically ordered list of tag names first
        sorted_tag_names = sorted(self.tags.keys(), key=str.lower)
        # Then get the list of sorted tag_name: tag_value tuples
        sorted_tags = [(tag_name, self.tags[tag_name]) for tag_name in sorted_tag_names]

        # Finally render, escape and return the tag string
        return ",".join("{0}={1}".format(format_string(k), format_string(v)) for k, v in sorted_tags)

    def get_output_timestamp(self):
        """
        Formats timestamp so it can be rendered to line protocol
        """
        return " {0}".format(self.timestamp) if self.timestamp else ""

    def to_line_protocol(self):
        """
        Converts the given metrics as a single line of InfluxDB line protocol
        """
        tags = self.get_output_tags()

        return "{0}{1} {2}{3}".format(
            self.get_output_measurement(),
            "," + tags if tags else '',
            self.get_output_values(),
            self.get_output_timestamp()
        )

==> pytelegraf-0.1.1-py2-none-any.whl: telegraf/protocol.py <==
from telegraf.utils import format_string, format_value


class Line(object):
    def __init__(self, measurement, values, tags={}, timestamp=None):
        assert measurement, "Must have measurement"
        assert values, "Must have values"

        # Name of the actual measurement
        self.measurement = measurement
        # Single value or a dict of value_name: value pairs
        self.values = values
        # Dict of tags if any
        self.tags = tags
        # User provided timestamp if any
        self.timestamp = timestamp

    def get_output_measurement(self):
        """
        Formats and escapes measurement name that can be rendered to line protocol
        """
        return format_string(self.measurement)

    def get_output_values(self):
        """
        Return an escaped string of comma separated value_name: value pairs
        """
        # Handle primitive values here and implicitly convert them to a dict because
        # it allows the API to be simpler.

        # Also influxDB mandates that each value also has a name so the default name
        # for any non-dict value is "value"
        if not isinstance(self.values, dict):
            metric_values = {'value': self.values}
        else:
            metric_values = self.values

        # Sort the values in lexicographically by value name
        sorted_values = sorted(metric_values.items())

        return ",".join("{0}={1}".format(format_string(k), format_value(v)) for k, v in sorted_values)

    def get_output_tags(self):
        """
        Return an escaped string of comma separated tag_name: tag_value pairs

        Tags should be sorted by key before being sent for best performance. The sort should
        match that from the Go bytes. Compare function (http://golang.org/pkg/bytes/#Compare).
        """

        # Sort the tags in lexicographically by tag name
        sorted_tags = sorted(self.tags.items())

        # Finally render, escape and return the tag string
        return ",".join("{0}={1}".format(format_string(k), format_string(v)) for k, v in sorted_tags)

    def get_output_timestamp(self):
        """
        Formats timestamp so it can be rendered to line protocol
        """
        return " {0}".format(self.timestamp) if self.timestamp else ""

    def to_line_protocol(self):
        """
        Converts the given metrics as a single line of InfluxDB line protocol
        """
        tags = self.get_output_tags()

        return "{0}{1} {2}{3}".format(
            self.get_output_measurement(),
            "," + tags if tags else '',
            self.get_output_values(),
            self.get_output_timestamp()
        )
